Learn R Programming

GPBayes (version 0.1.0-5.1)

CH: The Confluent Hypergeometric correlation function proposed by Ma and Bhadra (2019)

Description

This function computes the Confluent Hypergeometric correlation function given a distance matrix. The Confluent Hypergeometric correlation function is given by $$C(h) = \frac{\Gamma(\nu+\alpha)}{\Gamma(\nu)} \mathcal{U}\left(\alpha, 1-\nu, \biggr(\frac{h}{\beta}\biggr)^2 \right),$$ where \(\alpha\) is the tail decay parameter. \(\beta\) is the range parameter. \(\nu\) is the smoothness parameter. \(\mathcal{U}(\cdot)\) is the confluent hypergeometric function of the second kind. For details about this covariance, see Ma and Bhadra (2019) at https://arxiv.org/abs/1911.05865.

Usage

CH(d, range, tail, nu)

Value

a numerical matrix

Arguments

d

a matrix of distances

range

a numerical value containing the range parameter

tail

a numerical value containing the tail decay parameter

nu

a numerical value containing the smoothness parameter

Author

Pulong Ma mpulong@gmail.com

See Also

GPBayes-package, GaSP, gp, matern, kernel, ikernel