Learn R Programming

GPBayes (version 0.1.0-5.1)

cauchy: The generalized Cauchy correlation function

Description

This function computes the generalized Cauchy correlation function given a distance matrix. The generalized Cauchy covariance is given by $$C(h) = \left\{ 1 + \left( \frac{h}{\phi} \right)^{\nu} \right\}^{-\alpha/\nu},$$ where \(\phi\) is the range parameter. \(\alpha\) is the tail decay parameter. \(\nu\) is the smoothness parameter. The case where \(\nu=2\) corresponds to the Cauchy covariance model, which is infinitely differentiable.

Usage

cauchy(d, range, tail, nu)

Value

a numerical matrix

Arguments

d

a matrix of distances

range

a numerical value containing the range parameter

tail

a numerical value containing the tail decay parameter

nu

a numerical value containing the smoothness parameter

Author

Pulong Ma mpulong@gmail.com

See Also