This function finds the correlation parameter given effective range
cor.to.par(
d,
param,
family = "CH",
cor.target = 0.05,
lower = NULL,
upper = NULL,
tol = .Machine$double.eps
)a numerical value of correlation parameters
a numerical value containing the effective range
a list containing correlation parameters. The specification of
param should depend on the covariance model. If the parameter value is
NULL, this function will find its value given the effective range via
root-finding function uniroot.
For the Confluent Hypergeometric class, range is used to denote the range parameter \(\beta\). tail is used to denote the tail decay parameter \(\alpha\). nu is used to denote the smoothness parameter \(\nu\).
For the generalized Cauchy class, range is used to denote the range parameter \(\phi\). tail is used to denote the tail decay parameter \(\alpha\). nu is used to denote the smoothness parameter \(\nu\).
For the Matérn class, range is used to denote the range parameter \(\phi\). nu is used to denote the smoothness parameter \(\nu\). When \(\nu=0.5\), the Matérn class corresponds to the exponential covariance.
For the powered-exponential class, range is used to denote the range parameter \(\phi\). nu is used to denote the smoothness parameter. When \(\nu=2\), the powered-exponential class corresponds to the Gaussian covariance.
a string indicating the type of covariance structure. The following correlation functions are implemented:
The Confluent Hypergeometric correlation function is given by $$C(h) = \frac{\Gamma(\nu+\alpha)}{\Gamma(\nu)} \mathcal{U}\left(\alpha, 1-\nu, \left(\frac{h}{\beta}\right)^2\right),$$ where \(\alpha\) is the tail decay parameter. \(\beta\) is the range parameter. \(\nu\) is the smoothness parameter. \(\mathcal{U}(\cdot)\) is the confluent hypergeometric function of the second kind. For details about this covariance, see Ma and Bhadra (2019) at https://arxiv.org/abs/1911.05865.
The generalized Cauchy covariance is given by $$C(h) = \left\{ 1 + \left( \frac{h}{\phi} \right)^{\nu} \right\}^{-\alpha/\nu},$$ where \(\phi\) is the range parameter. \(\alpha\) is the tail decay parameter. \(\nu\) is the smoothness parameter.
The Matérn correlation function is given by $$C(h)=\frac{2^{1-\nu}}{\Gamma(\nu)} \left(\frac{h}{\phi} \right)^{\nu} \mathcal{K}_{\nu}\left( \frac{h}{\phi} \right),$$ where \(\phi\) is the range parameter. \(\nu\) is the smoothness parameter. \(\mathcal{K}_{\nu}(\cdot)\) is the modified Bessel function of the second kind of order \(\nu\).
The exponential correlation function is given by $$C(h)=\exp(-h/\phi),$$ where \(\phi\) is the range parameter. This is the Matérn correlation with \(\nu=0.5\).
The Matérn correlation with \(\nu=1.5\).
The Matérn correlation with \(\nu=2.5\).
a numerical value. The default value is 0.05, which means that correlation parameters are searched such that the correlation is approximately 0.05.
a numerical value. This sets the lower bound to find the
correlation parameter via the R function uniroot.
a numerical value. This sets the upper bound to find the
correlation parameter via the R function uniroot.
a numerical value. This sets the precision of the solution with default value
specified as the machine precision .Machine$double.eps in R.
Pulong Ma mpulong@gmail.com
GPBayes-package, GaSP, kernel, ikernel
range = cor.to.par(1,param=list(tail=0.5,nu=2.5), family="CH")
tail = cor.to.par(1,param=list(range=0.5,nu=2.5), family="CH")
range = cor.to.par(1,param=list(nu=2.5),family="matern")
Run the code above in your browser using DataLab