distance: Compute distances for two sets of inputs
Description
This function computes distances for two sets of inputs and returns
a R object.
Usage
distance(input1, input2, type = "isotropic", dtype = "Euclidean")
Value
a R object holding distances for two sets of inputs. If type is isotropic, a matrix of distances
is returned; if type is tensor or ARD, a list of distance matrices
along each input dimension is returned.
a numeric vector or matrix of distances
Arguments
input1
a matrix of inputs
input2
a matrix of inputs
type
a string indicating the form of distances with three froms supported currently: isotropic, tensor, ARD.
dtype
a string indicating distance type: Euclidean, GCD, where the latter indicates great circle distance.