This function simulates realizations from Gaussian processes.
gp.sim(
formula = ~1,
input,
param,
cov.model = list(family = "CH", form = "isotropic"),
dtype = "Euclidean",
nsample = 1,
seed = NULL
)a numerical vector or a matrix
an object of formula class that specifies regressors; see formula for details.
a matrix including inputs in a GaSP
a list including values for regression parameters, covariance parameters, and nugget variance parameter. The specification of param should depend on the covariance model.
The regression parameters are denoted by coeff. Default value is \(\mathbf{0}\).
The marginal variance or partial sill is denoted by sig2. Default value is 1.
The nugget variance parameter is denoted by nugget for all covariance models. Default value is 0.
For the Confluent Hypergeometric class, range is used to denote the range parameter \(\beta\). tail is used to denote the tail decay parameter \(\alpha\). nu is used to denote the smoothness parameter \(\nu\).
For the generalized Cauchy class, range is used to denote the range parameter \(\phi\). tail is used to denote the tail decay parameter \(\alpha\). nu is used to denote the smoothness parameter \(\nu\).
For the Matérn class, range is used to denote the range parameter \(\phi\). nu is used to denote the smoothness parameter \(\nu\). When \(\nu=0.5\), the Matérn class corresponds to the exponential covariance.
For the powered-exponential class, range is used to denote the range parameter \(\phi\). nu is used to denote the smoothness parameter. When \(\nu=2\), the powered-exponential class corresponds to the Gaussian covariance.
a list of two strings: family, form, where family indicates the family of covariance functions including the Confluent Hypergeometric class, the Matérn class, the Cauchy class, the powered-exponential class. form indicates the specific form of covariance structures including the isotropic form, tensor form, automatic relevance determination form.
The Confluent Hypergeometric correlation function is given by $$C(h) = \frac{\Gamma(\nu+\alpha)}{\Gamma(\nu)} \mathcal{U}\left(\alpha, 1-\nu, \left(\frac{h}{\beta}\right)^2\right),$$ where \(\alpha\) is the tail decay parameter. \(\beta\) is the range parameter. \(\nu\) is the smoothness parameter. \(\mathcal{U}(\cdot)\) is the confluent hypergeometric function of the second kind. For details about this covariance, see Ma and Bhadra (2019) at https://arxiv.org/abs/1911.05865.
The generalized Cauchy covariance is given by $$C(h) = \left\{ 1 + \left( \frac{h}{\phi} \right)^{\nu} \right\}^{-\alpha/\nu},$$ where \(\phi\) is the range parameter. \(\alpha\) is the tail decay parameter. \(\nu\) is the smoothness parameter with default value at 2.
The Matérn correlation function is given by $$C(h)=\frac{2^{1-\nu}}{\Gamma(\nu)} \left( \frac{h}{\phi} \right)^{\nu} \mathcal{K}_{\nu}\left( \frac{h}{\phi} \right),$$ where \(\phi\) is the range parameter. \(\nu\) is the smoothness parameter. \(\mathcal{K}_{\nu}(\cdot)\) is the modified Bessel function of the second kind of order \(\nu\).
The exponential correlation function is given by $$C(h)=\exp(-h/\phi),$$ where \(\phi\) is the range parameter. This is the Matérn correlation with \(\nu=0.5\).
The Matérn correlation with \(\nu=1.5\).
The Matérn correlation with \(\nu=2.5\).
The powered-exponential correlation function is given by $$C(h)=\exp\left\{-\left(\frac{h}{\phi}\right)^{\nu}\right\},$$ where \(\phi\) is the range parameter. \(\nu\) is the smoothness parameter.
The Gaussian correlation function is given by $$C(h)=\exp\left(-\frac{h^2}{\phi^2}\right),$$ where \(\phi\) is the range parameter.
This indicates the isotropic form of covariance functions. That is, $$C(\mathbf{h}) = C^0(\|\mathbf{h}\|; \boldsymbol \theta),$$ where \(\| \mathbf{h}\|\) denotes the Euclidean distance or the great circle distance for data on sphere. \(C^0(\cdot)\) denotes any isotropic covariance family specified in family.
This indicates the tensor product of correlation functions. That is, $$ C(\mathbf{h}) = \prod_{i=1}^d C^0(|h_i|; \boldsymbol \theta_i),$$ where \(d\) is the dimension of input space. \(h_i\) is the distance along the \(i\)th input dimension. This type of covariance structure has been often used in Gaussian process emulation for computer experiments.
This indicates the automatic relevance determination form. That is, $$C(\mathbf{h}) = C^0\left(\sqrt{\sum_{i=1}^d\frac{h_i^2}{\phi^2_i}}; \boldsymbol \theta \right),$$ where \(\phi_i\) denotes the range parameter along the \(i\)th input dimension.
a string indicating the type of distance:
Euclidean distance is used. This is the default choice.
Great circle distance is used for data on sphere.
an integer indicating the number of realizations from a Gaussian process
a number specifying random number seed
Pulong Ma mpulong@gmail.com
GPBayes-package, GaSP, gp
n=50
y.sim = gp.sim(input=seq(0,1,length=n),
param=list(range=0.5,nugget=0.1,nu=2.5),
cov.model=list(family="matern",form="isotropic"),
seed=123)
Run the code above in your browser using DataLab