Learn R Programming

GPBayes (version 0.1.0-5.1)

show,gp-method: Print the information an object of the gp class

Description

Print the information an object of the gp class

Usage

# S4 method for gp
show(object)

Arguments

object

an object of gp class