This function computes the Confluent Hypergeometric correlation function given a distance matrix. The Confluent Hypergeometric correlation function is given by $$C(h) = \frac{\Gamma(\nu+\alpha)}{\Gamma(\nu)} \mathcal{U}\left(\alpha, 1-\nu, \biggr(\frac{h}{\beta}\biggr)^2 \right),$$ where \(\alpha\) is the tail decay parameter. \(\beta\) is the range parameter. \(\nu\) is the smoothness parameter. \(\mathcal{U}(\cdot)\) is the confluent hypergeometric function of the second kind. For details about this covariance, see Ma and Bhadra (2019) at https://arxiv.org/abs/1911.05865.
CH(d, range, tail, nu)a numerical matrix
a matrix of distances
a numerical value containing the range parameter
a numerical value containing the tail decay parameter
a numerical value containing the smoothness parameter
Pulong Ma mpulong@gmail.com
GPBayes-package, GaSP, gp, matern, kernel, ikernel