This function computes the generalized Cauchy correlation function given a distance matrix. The generalized Cauchy covariance is given by $$C(h) = \left\{ 1 + \left( \frac{h}{\phi} \right)^{\nu} \right\}^{-\alpha/\nu},$$ where \(\phi\) is the range parameter. \(\alpha\) is the tail decay parameter. \(\nu\) is the smoothness parameter. The case where \(\nu=2\) corresponds to the Cauchy covariance model, which is infinitely differentiable.
cauchy(d, range, tail, nu)a numerical matrix
a matrix of distances
a numerical value containing the range parameter
a numerical value containing the tail decay parameter
a numerical value containing the smoothness parameter
Pulong Ma mpulong@gmail.com