This function computes the Matérn correlation function given a distance matrix. The Matérn correlation function is given by $$C(h)=\frac{2^{1-\nu}}{\Gamma(\nu)} \left(\frac{h}{\phi} \right)^{\nu} \mathcal{K}_{\nu}\left( \frac{h}{\phi} \right),$$ where \(\phi\) is the range parameter. \(\nu\) is the smoothness parameter. \(\mathcal{K}_{\nu}(\cdot)\) is the modified Bessel function of the second kind of order \(\nu\). The form of covariance includes the following special cases by specifying \(\nu\) to be 0.5, 1.5, 2.5.
\(\nu=0.5\) corresponds to the exponential correlation function (exp) of the form $$C(h) = \exp\left\{ - \frac{h}{\phi} \right\} $$
\(\nu=1.5\) corresponds to the Matérn correlation function with smoothness parameter 1.5 (matern_3_2) of the form $$C(h) = \left( 1 + \frac{h}{\phi} \right) \exp\left\{ - \frac{h}{\phi} \right\} $$
\(\nu=2.5\) corresponds to the Matérn correlation function with smoothness parameter 2.5 (matern_5_2) of the form $$C(h) = \left\{ 1 + \frac{h}{\phi} + \frac{1}{3}\left(\frac{h}{\phi}\right)^2 \right\} \exp\left\{ - \frac{h}{\phi} \right\} $$
matern(d, range, nu)a numerical matrix
a matrix of distances
a numerical value containing the range parameter
a numerical value containing the smoothness parameter
Pulong Ma mpulong@gmail.com
GPBayes-package, GaSP, gp, CH, kernel, ikernel